@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2001-2011 Jacek Sieka, arnetheduck on gmail point com
+ * Copyright (C) 2001-2012 Jacek Sieka, arnetheduck on gmail point com
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -13,24 +13,25 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#ifndef DCPLUSPLUS_DCPP_HASH_VALUE_H
-#define DCPLUSPLUS_DCPP_HASH_VALUE_H
+#pragma once
 
-//#include "FastAlloc.h"
+/*
+#include "FastAlloc.h"
+*/
 #include "Encoder.h"
 
 namespace dcpp {
 
 template<class Hasher>
-struct HashValue /*: FastAlloc<HashValue<Hasher> > HashValue<Hasher> */ {
+struct HashValue /* : FastAlloc<HashValue<Hasher> > */ {
     static const size_t BITS = Hasher::BITS;
     static const size_t BYTES = Hasher::BYTES;
 
     HashValue() { }
-    explicit HashValue(uint8_t* aData) { memcpy(data, aData, BYTES); }
+    explicit HashValue(const uint8_t* aData) { memcpy(data, aData, BYTES); }
     explicit HashValue(const std::string& base32) { Encoder::fromBase32(base32.c_str(), data, BYTES); }
     HashValue(const HashValue& rhs) { memcpy(data, rhs.data, BYTES); }
     HashValue& operator=(const HashValue& rhs) { memcpy(data, rhs.data, BYTES); return *this; }
@@ -46,17 +47,15 @@ struct HashValue /*: FastAlloc<HashValue<Hasher> > HashValue<Hasher> */ {
 
 } // namespace dcpp
 
-namespace std { namespace tr1 {
+namespace std {
 template<typename T>
 struct hash<dcpp::HashValue<T> > {
-        size_t operator()(const dcpp::HashValue<T>& rhs) const {
-            // RVO should handle this as efficiently as reinterpret_cast
-            size_t hvHash;
-            memcpy(&hvHash, rhs.data, sizeof(size_t));
-            return hvHash;
-        }
+    size_t operator()(const dcpp::HashValue<T>& rhs) const {
+        // RVO should handle this as efficiently as reinterpret_cast
+        size_t hvHash;
+        memcpy(&hvHash, rhs.data, sizeof(size_t));
+        return hvHash;
+    }
 };
-}
-}
 
-#endif // !defined(HASH_VALUE_H)
+}
